@@ -1,66 +1,10 @@
 """
-YT is a package written primarily in Python designed to make the task of
-running Enzo easier.  It contains facilities for creating Enzo data (currently
-in prototype form) as well as runnning Enzo simulations, simulating the actions
-of Enzo on various existing data, and analyzing output from Enzo in a
-wide-variety of methods.
-
-An ever-growing collection of documentation is also available at
-http://yt-project.org/doc/ . Additionally, there is a
-project site at http://yt-project.org/ with recipes, a wiki, a variety of
-ways of peering into the version control, and a bug-reporting system.
-
-YT is divided into several packages.
-
-frontends
----------
-
-This is where interfaces to codes are created.  Within each subdirectory of
-yt/frontends/ there must exist the following files, even if empty:
-
-* data_structures.py, where subclasses of AMRGridPatch, Dataset and
-  AMRHierarchy are defined.
-* io.py, where a subclass of IOHandler is defined.
-* misc.py, where any miscellaneous functions or classes are defined.
-* definitions.py, where any definitions specific to the frontend are
-  defined.  (i.e., header formats, etc.)
-
-visualization
--------------
-
-This is where all visualization modules are stored.  This includes plot
-collections, the volume rendering interface, and pixelization frontends.
-
-data_objects
-------------
-
-All objects that handle data, processed or unprocessed, not explicitly
-defined as visualization are located in here.  This includes the base
-classes for data regions, covering grids, time series, and so on.  This
-also includes derived fields and derived quantities.
-
-analysis_modules
-----------------
-
-This is where all mechanisms for processing data live.  This includes
-things like clump finding, halo profiling, halo finding, and so on.  This
-is something of a catchall, but it serves as a level of greater
-abstraction that simply data selection and modification.
-
-gui
----
-
-This is where all GUI components go.  Typically this will be some small
-tool used for one or two things, which contains a launching mechanism on
-the command line.
-
-utilities
----------
-
-All broadly useful code that doesn't clearly fit in one of the other
-categories goes here.
-
+yt is a toolkit for analyzing and visualizing volumetric data.
 
+* Website: http://yt-project.org
+* Documentation: http://yt-project.org/doc
+* Data hub: http://hub.yt
+* Contribute: http://github.com/yt-project/yt
 
 """
 
@@ -72,7 +16,7 @@ categories goes here.
 # The full license is in the file COPYING.txt, distributed with this software.
 #-----------------------------------------------------------------------------
 
-__version__ = "3.3.3"
+__version__ = "3.5.0"
 
 # First module imports
 import numpy as np # For modern purposes
@@ -93,17 +37,25 @@ from yt.funcs import \
     parallel_profile, \
     enable_plugins, \
     memory_checker, \
-    deprecated_class
+    deprecated_class, \
+    toggle_interactivity
 from yt.utilities.logger import ytLogger as mylog
 
 import yt.utilities.physical_constants as physical_constants
 import yt.units as units
+from yt.units.unit_object import define_unit
 from yt.units.yt_array import \
     YTArray, \
     YTQuantity, \
     uconcatenate, \
+    ucross, \
     uintersect1d, \
     uunion1d, \
+    unorm, \
+    udot, \
+    ustack, \
+    uvstack, \
+    uhstack, \
     loadtxt, \
     savetxt
 
@@ -118,7 +70,8 @@ from yt.fields.api import \
     ValidateSpatial, \
     ValidateGridType, \
     add_field, \
-    derived_field
+    derived_field, \
+    add_xray_emissivity_field
 
 from yt.data_objects.api import \
     DatasetSeries, ImageArray, \
@@ -151,11 +104,13 @@ from yt.visualization.api import \
     FixedResolutionBuffer, ObliqueFixedResolutionBuffer, \
     write_bitmap, write_image, \
     apply_colormap, scale_image, write_projection, \
-    SlicePlot, AxisAlignedSlicePlot, OffAxisSlicePlot, \
-    ProjectionPlot, OffAxisProjectionPlot, \
+    SlicePlot, AxisAlignedSlicePlot, OffAxisSlicePlot, LinePlot, \
+    LineBuffer, ProjectionPlot, OffAxisProjectionPlot, \
     show_colormaps, add_cmap, make_colormap, \
     ProfilePlot, PhasePlot, ParticlePhasePlot, \
-    ParticleProjectionPlot, ParticleImageBuffer, ParticlePlot
+    ParticleProjectionPlot, ParticleImageBuffer, ParticlePlot, \
+    FITSImageData, FITSSlice, FITSProjection, FITSOffAxisSlice, \
+    FITSOffAxisProjection, plot_2d
 
 from yt.visualization.volume_rendering.api import \
     volume_render, create_scene, ColorTransferFunction, TransferFunction, \
