@@ -24,6 +24,7 @@ import warnings
 
 from collections import defaultdict
 from yt.extern.six import add_metaclass, string_types
+from six.moves import cPickle
 
 from yt.config import ytcfg
 from yt.fields.derived_field import \
@@ -66,7 +67,9 @@ from yt.utilities.minimal_representation import \
 from yt.units.yt_array import \
     YTArray, \
     YTQuantity
-from yt.units.unit_systems import create_code_unit_system
+from yt.units.unit_systems import \
+    create_code_unit_system, \
+    _make_unit_system_copy
 from yt.data_objects.region_expression import \
     RegionExpression
 from yt.geometry.coordinates.api import \
@@ -80,7 +83,7 @@ from yt.geometry.coordinates.api import \
     InternalGeographicCoordinateHandler
 
 # We want to support the movie format in the future.
-# When such a thing comes to pass, I'll move all the stuff that is contant up
+# When such a thing comes to pass, I'll move all the stuff that is constant up
 # to here, and then have it instantiate EnzoDatasets as appropriate.
 
 _cached_datasets = weakref.WeakValueDictionary()
@@ -240,6 +243,7 @@ class Dataset(object):
     fields = requires_index("fields")
     _instantiated = False
     _particle_type_counts = None
+    _ionization_label_format = 'roman_numeral'
 
     def __new__(cls, filename=None, *args, **kwargs):
         if not isinstance(filename, string_types):
@@ -252,14 +256,15 @@ class Dataset(object):
                 obj.__init__(filename, *args, **kwargs)
             return obj
         apath = os.path.abspath(filename)
+        cache_key = (apath, cPickle.dumps(args), cPickle.dumps(kwargs))
         if ytcfg.getboolean("yt","skip_dataset_cache"):
             obj = object.__new__(cls)
-        elif apath not in _cached_datasets:
+        elif cache_key not in _cached_datasets:
             obj = object.__new__(cls)
             if obj._skip_cache is False:
-                _cached_datasets[apath] = obj
+                _cached_datasets[cache_key] = obj
         else:
-            obj = _cached_datasets[apath]
+            obj = _cached_datasets[cache_key]
         return obj
 
     def __init__(self, filename, dataset_type=None, file_style=None,
@@ -351,7 +356,7 @@ class Dataset(object):
             return hashlib.md5(s.encode('utf-8')).hexdigest()
         except ImportError:
             return s.replace(";", "*")
-   
+
     _checksum = None
     @property
     def checksum(self):
@@ -563,13 +568,35 @@ class Dataset(object):
                 mylog.debug("zero common fields: skipping particle union 'all'")
         self.field_info.setup_extra_union_fields()
         mylog.debug("Loading field plugins.")
-        self.field_info.load_all_plugins()
+        self.field_info.load_all_plugins(self.default_fluid_type)
         deps, unloaded = self.field_info.check_derived_fields()
         self.field_dependencies.update(deps)
         self.fields = FieldTypeContainer(self)
         self.index.field_list = sorted(self.field_list)
         self._last_freq = (None, None)
 
+    def set_field_label_format(self, format_property, value):
+        """
+        Set format properties for how fields will be written
+        out. Accepts 
+
+        format_property : string indicating what property to set
+        value: the value to set for that format_property
+        """
+        available_formats = {"ionization_label":("plus_minus", "roman_numeral")}
+        if format_property in available_formats:
+            if value in available_formats[format_property]:
+                setattr(self, "_%s_format" % format_property, value)
+            else:
+                raise ValueError("{0} not an acceptable value for format_property "
+                        "{1}. Choices are {2}.".format(value, format_property,
+                            available_formats[format_property]))
+        else:
+            raise ValueError("{0} not a recognized format_property. Available"
+                             "properties are: {1}".format(format_property,
+                                                         list(available_formats.keys())))
+
+
     def setup_deprecated_fields(self):
         from yt.fields.field_aliases import _field_name_aliases
         added = []
@@ -653,6 +680,12 @@ class Dataset(object):
         return len(new_fields)
 
     def add_particle_filter(self, filter):
+        """Add particle filter to the dataset.
+
+        Add ``filter`` to the dataset and set up relavent derived_field.
+        It will also add any ``filtered_type`` that the ``filter`` depends on.
+
+        """
         # This requires an index
         self.index
         # This is a dummy, which we set up to enable passthrough of "all"
@@ -661,11 +694,12 @@ class Dataset(object):
         self.known_filters[n] = None
         if isinstance(filter, string_types):
             used = False
-            for f in filter_registry[filter]:
-                used = self._setup_filtered_type(f)
-                if used:
-                    filter = f
-                    break
+            f = filter_registry.get(filter, None)
+            if f is None:
+                return False
+            used = self._setup_filtered_type(f)
+            if used:
+                filter = f
         else:
             used = self._setup_filtered_type(filter)
         if not used:
@@ -675,6 +709,15 @@ class Dataset(object):
         return True
 
     def _setup_filtered_type(self, filter):
+        # Check if the filtered_type of this filter is known, 
+        # otherwise add it first if it is in the filter_registry
+        if filter.filtered_type not in self.known_filters.keys():
+            if filter.filtered_type in filter_registry:
+                add_success = self.add_particle_filter(filter.filtered_type)
+                if add_success:
+                    mylog.info("Added filter dependency '%s' for '%s'",
+                       filter.filtered_type, filter.name)
+
         if not filter.available(self.derived_field_list):
             raise YTIllDefinedParticleFilter(
                 filter, filter.missing(self.derived_field_list))
@@ -691,8 +734,10 @@ class Dataset(object):
                 # Now we append the dependencies
                 fd[filter.name, fn[1]] = fd[fn]
         if available:
-            self.particle_types += (filter.name,)
-            self.filtered_particle_types.append(filter.name)
+            if filter.name not in self.particle_types:
+                self.particle_types += (filter.name,)
+            if filter.name not in self.filtered_particle_types:
+                self.filtered_particle_types.append(filter.name)
             new_fields = self._setup_particle_types([filter.name])
             deps, _ = self.field_info.check_derived_fields(new_fields)
             self.field_dependencies.update(deps)
@@ -762,19 +807,7 @@ class Dataset(object):
                 setattr(self, name,
                     _unsupported_object(self, name))
                 continue
-            cname = cls.__name__
-            if cname.endswith("Base"): cname = cname[:-4]
             self._add_object_class(name, cls)
-        if not np.all(self.refine_by == 2) and hasattr(self, 'proj') and \
-            hasattr(self, 'overlap_proj'):
-            mylog.warning("Refine by something other than two: reverting to"
-                        + " overlap_proj")
-            self.proj = self.overlap_proj
-        if self.dimensionality < 3 and hasattr(self, 'proj') and \
-            hasattr(self, 'overlap_proj'):
-            mylog.warning("Dimensionality less than 3: reverting to"
-                        + " overlap_proj")
-            self.proj = self.overlap_proj
         self.object_types.sort()
 
     def _add_object_class(self, name, base):
@@ -793,7 +826,8 @@ class Dataset(object):
             source.quantities.max_location(field)
         mylog.info("Max Value is %0.5e at %0.16f %0.16f %0.16f",
               max_val, mx, my, mz)
-        return max_val, self.arr([mx, my, mz], 'code_length', dtype="float64")
+        center = self.arr([mx, my, mz], dtype="float64").to('code_length')
+        return max_val, center
 
     def find_min(self, field):
         """
@@ -805,7 +839,8 @@ class Dataset(object):
             source.quantities.min_location(field)
         mylog.info("Min Value is %0.5e at %0.16f %0.16f %0.16f",
               min_val, mx, my, mz)
-        return min_val, self.arr([mx, my, mz], 'code_length', dtype="float64")
+        center = self.arr([mx, my, mz], dtype="float64").to('code_length')
+        return min_val, center
 
     def find_field_values_at_point(self, fields, coords):
         """
@@ -841,10 +876,10 @@ class Dataset(object):
 
         # This may be slow because it creates a data object for each point
         for field_index, field in enumerate(fields):
-            funit = self._get_field_info[field].units
+            funit = self._get_field_info(field).units
             out.append(self.arr(np.empty((len(coords),)), funit))
             for coord_index, coord in enumerate(coords):
-                out[field_index][coord_index] = self.point(coord)[fields]
+                out[field_index][coord_index] = self.point(coord)[field]
         if len(fields) == 1:
             return out[0]
         else:
@@ -940,10 +975,11 @@ class Dataset(object):
         create_code_unit_system(self.unit_registry, 
                                 current_mks_unit=current_mks_unit)
         if unit_system == "code":
-            unit_system = self.unit_registry.unit_system_id
+            unit_system = unit_system_registry[self.unit_registry.unit_system_id]
         else:
-            unit_system = str(unit_system).lower()
-        self.unit_system = unit_system_registry[unit_system]
+            sys_name = str(unit_system).lower()
+            unit_system = _make_unit_system_copy(self.unit_registry, sys_name)
+        self.unit_system = unit_system
 
     def _create_unit_registry(self):
         self.unit_registry = UnitRegistry()
@@ -951,6 +987,8 @@ class Dataset(object):
         self.unit_registry.add("code_length", 1.0, dimensions.length)
         self.unit_registry.add("code_mass", 1.0, dimensions.mass)
         self.unit_registry.add("code_density", 1.0, dimensions.density)
+        self.unit_registry.add("code_specific_energy", 1.0,
+                               dimensions.energy / dimensions.mass)
         self.unit_registry.add("code_time", 1.0, dimensions.time)
         self.unit_registry.add("code_magnetic", 1.0, dimensions.magnetic_field)
         self.unit_registry.add("code_temperature", 1.0, dimensions.temperature)
@@ -1028,10 +1066,12 @@ class Dataset(object):
             self.mass_unit / (self.length_unit * (self.time_unit)**2))
         temperature_unit = getattr(self, "temperature_unit", 1.0)
         density_unit = getattr(self, "density_unit", self.mass_unit / self.length_unit**3)
+        specific_energy_unit = getattr(self, "specific_energy_unit", vel_unit**2)
         self.unit_registry.modify("code_velocity", vel_unit)
         self.unit_registry.modify("code_temperature", temperature_unit)
         self.unit_registry.modify("code_pressure", pressure_unit)
         self.unit_registry.modify("code_density", density_unit)
+        self.unit_registry.modify("code_specific_energy", specific_energy_unit)
         # domain_width does not yet exist
         if (self.domain_left_edge is not None and
             self.domain_right_edge is not None):
