@@ -120,9 +120,12 @@ class DatasetSeries(object):
         This parameter governs the behavior when .piter() is called on the
         resultant DatasetSeries object.  If this is set to False, the time
         series will not iterate in parallel when .piter() is called.  If
-        this is set to either True or an integer, it will be iterated with
-        1 or that integer number of processors assigned to each parameter
-        file provided to the loop.
+        this is set to either True, one processor will be allocated for
+        each iteration of the loop. If this is set to an integer, the loop
+        will be parallelized over this many workgroups. It the integer
+        value is less than the total number of available processors,
+        more than one processor will be allocated to a given loop iteration,
+        causing the functionality within the loop to be run in parallel.
     setup_function : callable, accepts a ds
         This function will be called whenever a dataset is loaded.
     mixed_dataset_types : True or False, default False
@@ -401,7 +404,7 @@ class DatasetSeries(object):
         self._dataset_cls = ds.__class__
         return ds
 
-    def particle_trajectories(self, indices, fields=None, suppress_logging=False):
+    def particle_trajectories(self, indices, fields=None, suppress_logging=False, ptype=None):
         r"""Create a collection of particle trajectories in time over a series of
         datasets.
 
@@ -418,6 +421,8 @@ class DatasetSeries(object):
         suppress_logging : boolean
             Suppress yt's logging when iterating over the simulation time
             series. Default: False
+        ptype : str, optional
+            Only use this particle type. Default: None, which uses all particle type.
 
         Examples
         --------
@@ -433,8 +438,14 @@ class DatasetSeries(object):
         >>> trajs = ts.particle_trajectories(indices, fields=fields)
         >>> for t in trajs :
         >>>     print t["particle_velocity_x"].max(), t["particle_velocity_x"].min()
+
+        Note
+        ----
+        This function will fail if there are duplicate particle ids or if some of the particle
+        disappear.
         """
-        return ParticleTrajectories(self, indices, fields=fields, suppress_logging=suppress_logging)
+        return ParticleTrajectories(self, indices, fields=fields, suppress_logging=suppress_logging,
+                                    ptype=ptype)
 
 class TimeSeriesQuantitiesContainer(object):
     def __init__(self, data_object, quantities):
