@@ -17,21 +17,28 @@ import sys, types, os, glob, time, importlib
 from yt.extern.six.moves import cPickle as pickle
 
 _frontends = [
+    'ahf',
     'art',
     'artio',
     'athena',
+    'athena_pp',
     'boxlib',
     'chombo',
     'eagle',
     'enzo',
+    'enzo_p',
+    'exodus_ii',
     'fits',
     'flash',
     'gadget',
     'gadget_fof',
+    'gamer',
     'gdf',
+    'gizmo',
     'halo_catalog',
     'http_stream',
     'moab',
+    'open_pmd',
     'owls',
     'owls_subfind',
     'ramses',
@@ -39,6 +46,7 @@ _frontends = [
     'sdf',
     'stream',
     'tipsy',
+    'ytdata',
 ]
 
 class _frontend_container:
