@@ -12,10 +12,11 @@ The data-file handling functions
 #
 # The full license is in the file COPYING.txt, distributed with this software.
 #-----------------------------------------------------------------------------
+
 from yt.utilities.io_handler import \
-           BaseIOHandler
+    BaseIOHandler
 import numpy as np
-from yt.funcs import mylog, defaultdict
+from yt.funcs import mylog
 from .data_structures import chk23
 
 float_size = {"float":np.dtype(">f4").itemsize,
@@ -86,7 +87,7 @@ class IOHandlerAthena(BaseIOHandler):
         sl[axis] = slice(coord, coord + 1)
         if grid.ds.field_ordering == 1:
             sl.reverse()
-        return self._read_data_set(grid, field)[sl]
+        return self._read_data_set(grid, field)[tuple(sl)]
 
     def _read_fluid_selection(self, chunks, selector, fields, size):
         chunks = list(chunks)
