@@ -17,8 +17,11 @@ import numpy as np
 import glob
 import os
 
+from math import ceil
+
 from yt.convenience import \
-    load, \
+    load
+from yt.funcs import \
     only_on_root
 from yt.data_objects.time_series import \
     SimulationTimeSeries, DatasetSeries
@@ -26,18 +29,19 @@ from yt.units import dimensions
 from yt.units.unit_registry import \
     UnitRegistry
 from yt.units.yt_array import \
-    YTArray, YTQuantity
+    YTArray
 from yt.utilities.cosmology import \
     Cosmology
 from yt.utilities.exceptions import \
     InvalidSimulationTimeSeries, \
     MissingParameter, \
-    NoStoppingCondition
+    NoStoppingCondition, \
+    YTOutputNotIdentified
 from yt.utilities.logger import ytLogger as \
     mylog
 from yt.utilities.parallel_tools.parallel_analysis_interface import \
     parallel_objects
-    
+
 class EnzoSimulation(SimulationTimeSeries):
     r"""
     Initialize an Enzo Simulation object.
@@ -62,10 +66,10 @@ class EnzoSimulation(SimulationTimeSeries):
     Examples
     --------
     >>> import yt
-    >>> es = yt.simulation("my_simulation.par", "Enzo")
+    >>> es = yt.simulation("enzo_tiny_cosmology/32Mpc_32.enzo", "Enzo")
     >>> es.get_time_series()
     >>> for ds in es:
-    ...     print ds.current_time
+    ...     print(ds.current_time)
 
     """
 
@@ -77,7 +81,8 @@ class EnzoSimulation(SimulationTimeSeries):
 
     def _set_units(self):
         self.unit_registry = UnitRegistry()
-        self.unit_registry.lut["code_time"] = (1.0, dimensions.time)
+        self.unit_registry.add("code_time", 1.0, dimensions.time)
+        self.unit_registry.add("code_length", 1.0, dimensions.length)
         if self.cosmological_simulation:
             # Instantiate EnzoCosmology object for units and time conversions.
             self.cosmology = \
@@ -97,10 +102,16 @@ class EnzoSimulation(SimulationTimeSeries):
                                        dimensions.length, "\\rm{%s}/(1+z)" % my_unit)
             self.length_unit = self.quan(self.box_size, "Mpccm / h",
                                          registry=self.unit_registry)
-            self.box_size = self.length_unit
         else:
             self.time_unit = self.quan(self.parameters["TimeUnits"], "s")
+            self.length_unit = self.quan(self.parameters["LengthUnits"], "cm")
+        self.box_size = self.length_unit
+        self.domain_left_edge = self.domain_left_edge * self.length_unit
+        self.domain_right_edge = self.domain_right_edge * self.length_unit
         self.unit_registry.modify("code_time", self.time_unit)
+        self.unit_registry.modify("code_length", self.length_unit)
+        self.unit_registry.add("unitary", float(self.box_size.in_base()),
+                               self.length_unit.units.dimensions)
 
     def get_time_series(self, time_data=True, redshift_data=True,
                         initial_time=None, final_time=None,
@@ -130,21 +141,21 @@ class EnzoSimulation(SimulationTimeSeries):
             datasets for time series.
             Default: True.
         initial_time : tuple of type (float, str)
-            The earliest time for outputs to be included.  This should be 
+            The earliest time for outputs to be included.  This should be
             given as the value and the string representation of the units.
-            For example, (5.0, "Gyr").  If None, the initial time of the 
-            simulation is used.  This can be used in combination with 
+            For example, (5.0, "Gyr").  If None, the initial time of the
+            simulation is used.  This can be used in combination with
             either final_time or final_redshift.
             Default: None.
         final_time : tuple of type (float, str)
-            The latest time for outputs to be included.  This should be 
+            The latest time for outputs to be included.  This should be
             given as the value and the string representation of the units.
-            For example, (13.7, "Gyr"). If None, the final time of the 
-            simulation is used.  This can be used in combination with either 
+            For example, (13.7, "Gyr"). If None, the final time of the
+            simulation is used.  This can be used in combination with either
             initial_time or initial_redshift.
             Default: None.
         times : tuple of type (float array, str)
-            A list of times for which outputs will be found and the units 
+            A list of times for which outputs will be found and the units
             of those values.  For example, ([0, 1, 2, 3], "s").
             Default: None.
         initial_redshift : float
@@ -191,26 +202,14 @@ class EnzoSimulation(SimulationTimeSeries):
         --------
 
         >>> import yt
-        >>> es = yt.simulation("my_simulation.par", "Enzo")
-        
-        >>> es.get_time_series(initial_redshift=10, final_time=(13.7, "Gyr"), 
+        >>> es = yt.simulation("enzo_tiny_cosmology/32Mpc_32.enzo", "Enzo")
+        >>> es.get_time_series(initial_redshift=10, final_time=(13.7, "Gyr"),
                                redshift_data=False)
-
-        >>> es.get_time_series(redshifts=[3, 2, 1, 0])
-
-        >>> es.get_time_series(final_cycle=100000)
-
-        >>> # after calling get_time_series
-        >>> for ds in es.piter():
-        ...     p = ProjectionPlot(ds, 'x', "density")
-        ...     p.save()
-
-        >>> # An example using the setup_function keyword
-        >>> def print_time(ds):
-        ...     print ds.current_time
-        >>> es.get_time_series(setup_function=print_time)
         >>> for ds in es:
-        ...     SlicePlot(ds, "x", "Density").save()
+        ...     print(ds.current_time)
+        >>> es.get_time_series(redshifts=[3, 2, 1, 0])
+        >>> for ds in es:
+        ...     print(ds.current_time)
 
         """
 
@@ -301,7 +300,7 @@ class EnzoSimulation(SimulationTimeSeries):
         for output in my_outputs:
             if os.path.exists(output['filename']):
                 init_outputs.append(output['filename'])
-            
+
         DatasetSeries.__init__(self, outputs=init_outputs, parallel=parallel,
                                 setup_function=setup_function)
         mylog.info("%d outputs loaded into time series.", len(init_outputs))
@@ -385,7 +384,7 @@ class EnzoSimulation(SimulationTimeSeries):
                           'final_redshift': 'CosmologyFinalRedshift'}
             self.cosmological_simulation = 1
             for a, v in cosmo_attr.items():
-                if not v in self.parameters:
+                if v not in self.parameters:
                     raise MissingParameter(self.parameter_filename, v)
                 setattr(self, a, self.parameters[v])
         else:
@@ -412,7 +411,7 @@ class EnzoSimulation(SimulationTimeSeries):
 
         self.all_time_outputs = []
         if self.final_time is None or \
-            not 'dtDataDump' in self.parameters or \
+            'dtDataDump' not in self.parameters or \
             self.parameters['dtDataDump'] <= 0.0: return []
 
         index = 0
@@ -441,7 +440,7 @@ class EnzoSimulation(SimulationTimeSeries):
         mylog.warn('Calculating cycle outputs.  Dataset times will be unavailable.')
 
         if self.stop_cycle is None or \
-            not 'CycleSkipDataDump' in self.parameters or \
+            'CycleSkipDataDump' not in self.parameters or \
             self.parameters['CycleSkipDataDump'] <= 0.0: return []
 
         self.all_time_outputs = []
@@ -544,6 +543,7 @@ class EnzoSimulation(SimulationTimeSeries):
         self.parameters['StopCycle'] = 100000
         self.parameters['dtDataDump'] = 0.
         self.parameters['CycleSkipDataDump'] = 0.
+        self.parameters['LengthUnits'] = 1.
         self.parameters['TimeUnits'] = 1.
 
     def _find_outputs(self):
@@ -583,11 +583,15 @@ class EnzoSimulation(SimulationTimeSeries):
         Check a list of files to see if they are valid datasets.
         """
 
-        only_on_root(mylog.info, "Checking %d potential outputs.", 
+        only_on_root(mylog.info, "Checking %d potential outputs.",
                      len(potential_outputs))
 
         my_outputs = {}
-        for my_storage, output in parallel_objects(potential_outputs, 
+        llevel = mylog.level
+        # suppress logging as we load every dataset, unless set to debug
+        if llevel > 10 and llevel < 40:
+            mylog.setLevel(40)
+        for my_storage, output in parallel_objects(potential_outputs,
                                                    storage=my_outputs):
             if self.parameters['DataDumpDir'] in output:
                 dir_key = self.parameters['DataDumpDir']
@@ -609,6 +613,7 @@ class EnzoSimulation(SimulationTimeSeries):
                             my_storage.result['redshift'] = ds.current_redshift
                 except YTOutputNotIdentified:
                     mylog.error('Failed to load %s', filename)
+        mylog.setLevel(llevel)
         my_outputs = [my_output for my_output in my_outputs.values() \
                       if my_output is not None]
 
@@ -623,7 +628,6 @@ class EnzoSimulation(SimulationTimeSeries):
         mylog.info("Writing redshift output list to %s.", filename)
         f = open(filename, 'w')
         for q, output in enumerate(outputs):
-            z_string = "%%s[%%d] = %%.%df" % decimals
             f.write(("CosmologyOutputRedshift[%d] = %."
                      + str(decimals) + "f\n") %
                     ((q + start_index), output['redshift']))
@@ -639,8 +643,9 @@ class EnzoCosmology(Cosmology):
                            omega_curvature=omega_curvature,
                            unit_registry=unit_registry)
         self.initial_redshift = initial_redshift
+        self.initial_time = self.t_from_z(self.initial_redshift)
         # time units = 1 / sqrt(4 * pi * G rho_0 * (1 + z_i)**3),
         # rho_0 = (3 * Omega_m * h**2) / (8 * pi * G)
-        self.time_unit = ((1.5 * self.omega_matter * self.hubble_constant**2 * 
+        self.time_unit = ((1.5 * self.omega_matter * self.hubble_constant**2 *
                            (1 + self.initial_redshift)**3)**-0.5).in_units("s")
         self.time_unit.units.registry = self.unit_registry
