@@ -5,8 +5,6 @@ Data structures for Gadget frontend
 
 
 """
-from __future__ import print_function
-
 #-----------------------------------------------------------------------------
 # Copyright (c) 2014, yt Development Team.
 #
@@ -50,35 +48,146 @@ def _fix_unit_ordering(unit):
     return unit
 
 
-def _get_gadget_format(filename):
-    # check and return gadget binary format with file endianness
-    ff = open(filename, 'rb')
-    (rhead,) = struct.unpack('<I', ff.read(4))
-    ff.close()
-    if (rhead == 134217728):
-        return 2, '>'
-    elif (rhead == 8):
-        return 2, '<'
-    elif (rhead == 65536):
-        return 1, '>'
-    elif (rhead == 256):
-        return 1, '<'
-    else:
-        raise RuntimeError("Incorrect Gadget format %s!" % str(rhead))
+def _byte_swap_32(x):
+    return struct.unpack('>I', struct.pack('<I', x))[0]
+
+
+class GadgetBinaryHeader(object):
+    """A convenient interface to Gadget binary header.
+    
+    This is a helper class to facilitate the main dataset and IO classes.
+    The main usage is through the GadgetDataset._header attribute. It is also
+    used stand-alone in GadgetDataset._is_valid method.
+    """
+    _placeholder_keys = ['unused', 'empty']
+
+    def __init__(self, filename, header_spec):
+        self.filename = filename
+        if isinstance(header_spec, string_types):
+            header_spec = [header_spec]
+        self.spec = [GadgetDataset._setup_binary_spec(hs, gadget_header_specs)
+                     for hs in header_spec]
+
+    @property
+    def float_type(self):
+        """Determine whether the floats are single or double precision."""
+        gformat, endianswap = self.gadget_format
+        # We do not currently support double precision snapshot format 2
+        if gformat == 2:
+            return 'f4'
+        else:
+            hvals = self.value
+            np0 = sum(hvals['Npart'])
+            with self.open() as f:
+                f.seek(self.position_offset)
+                # Calculate particle number assuming single precision
+                np1 = struct.unpack(endianswap + 'I', f.read(4))[0] / (4 * 3)
+            if np1 == np0:
+                return 'f4'
+            elif np1 == 2 * np0:
+                return 'f8'
+            else:
+                raise RuntimeError(
+                    "Gadget snapshot file is likely corrupted! "
+                    "Cannot determine float type."
+                )
+
+    @property
+    def gadget_format(self):
+        """Determine Gadget snapshot format and endianness.
+        
+        The difference between Gadget snapshot format 1 and 2 can be told from
+        the first 4 bytes of the file. For format 1, it's the header size. For
+        format 2, it's always 8.
+        """
+        first_header_size = self.size[0]
+        # Read the first 4 bytes assuming little endian int32
+        with self.open() as f:
+            (rhead,) = struct.unpack('<I', f.read(4))
+        # Foramt 1?
+        if rhead == first_header_size:
+            return 1, '<'
+        elif rhead == _byte_swap_32(first_header_size):
+            return 1, '>'
+        # Format 2?
+        elif rhead == 8:
+            return 2, '<'
+        elif rhead == _byte_swap_32(8):
+            return 2, '>'
+        else:
+            raise RuntimeError(
+                "Gadget snapshot file is likely corrupted! "
+                "The first 4 bytes represent %s (as little endian int32). "
+                "But we are looking for %s (for format 1) or 8 (for format 2)."
+                % (rhead, first_header_size)
+            )
+
+    @property
+    def position_offset(self):
+        """Offset to the position block."""
+        n_header = len(self.size)
+        offset = 8 * n_header + sum(self.size)
+        if self.gadget_format[0] == 2:
+            offset += SNAP_FORMAT_2_OFFSET * (n_header + 1)
+        return offset
+
+    @property
+    def size(self):
+        """Header size in bytes."""
+        def single_header_size(single_header_spec):
+            return sum(field[1] * np.dtype(field[2]).itemsize
+                       for field in single_header_spec)
+        return [single_header_size(spec) for spec in self.spec]
+
+    @property
+    def value(self):
+        """Header values as a dictionary."""
+        # The entries in this header are capitalized and named to match Table 4
+        # in the GADGET-2 user guide.
+        gformat, endianswap = self.gadget_format
+        # Read header
+        with self.open() as f:
+            hvals = {}
+            for spec in self.spec:
+                if gformat == 2:
+                    f.seek(f.tell() + SNAP_FORMAT_2_OFFSET)
+                hvals_new = read_record(f, spec, endian=endianswap)
+                hvals.update(hvals_new)
+        # Remove placeholder keys
+        for key in self._placeholder_keys:
+            if key in hvals:
+                del hvals[key]
+        # Convert length 1 list to scalar value
+        for i in hvals:
+            if len(hvals[i]) == 1:
+                hvals[i] = hvals[i][0]
+        return hvals
+
+    def open(self):
+        """Open snapshot file."""
+        for filename in [self.filename, self.filename + '.0']:
+            if os.path.exists(filename):
+                return open(filename, 'rb')
+        raise RuntimeError("Snapshot file %s does not exist." % self.filename)
+
+    def validate(self):
+        """Validate data integrity."""
+        try:
+            self.open().close()
+            self.gadget_format
+            self.float_type
+        except:
+            return False
+        return True
 
 
 class GadgetBinaryFile(ParticleFile):
     def __init__(self, ds, io, filename, file_id):
-        gformat = _get_gadget_format(filename)
-        with open(filename, "rb") as f:
-            if gformat[0] == 2:
-                f.seek(f.tell() + SNAP_FORMAT_2_OFFSET)
-            self.header = read_record(f, ds._header_spec, endian=gformat[1])
-            if gformat[0] == 2:
-                f.seek(f.tell() + SNAP_FORMAT_2_OFFSET)
-            self._position_offset = f.tell()
-            f.seek(0, os.SEEK_END)
-            self._file_size = f.tell()
+        header = ds._header
+        self.header = header.value
+        self._position_offset = header.position_offset
+        with header.open() as f:
+            self._file_size = f.seek(0, os.SEEK_END)
 
         super(GadgetBinaryFile, self).__init__(ds, io, filename, file_id)
 
@@ -114,8 +223,20 @@ class GadgetDataset(SPHDataset):
                  w_a = 0.0):
         if self._instantiated:
             return
-        self._header_spec = self._setup_binary_spec(
-            header_spec, gadget_header_specs)
+        self._header = GadgetBinaryHeader(filename, header_spec)
+        header_size = self._header.size
+        if header_size != [256]:
+            only_on_root(
+                mylog.warn,
+                "Non-standard header size is detected! "
+                "Gadget-2 standard header is 256 bytes, but yours is %s. "
+                "Make sure a non-standard header is actually expected. "
+                "Otherwise something is wrong, "
+                "and you might want to check how the dataset is loaded. "
+                "Futher information about header specification can be found in "
+                "https://yt-project.org/docs/dev/examining/loading_data.html#header-specification.",
+                header_size
+            )
         self._field_spec = self._setup_binary_spec(
             field_spec, gadget_field_specs)
         self._ptype_spec = self._setup_binary_spec(
@@ -157,8 +278,9 @@ class GadgetDataset(SPHDataset):
             self.length_unit.convert_to_units('kpc')
             self.mass_unit.convert_to_units('Msun')
 
-    def _setup_binary_spec(self, spec, spec_dict):
-        if isinstance(spec, str):
+    @classmethod
+    def _setup_binary_spec(cls, spec, spec_dict):
+        if isinstance(spec, string_types):
             _hs = ()
             for hs in spec.split("+"):
                 _hs += spec_dict[hs]
@@ -169,17 +291,7 @@ class GadgetDataset(SPHDataset):
         return os.path.basename(self.parameter_filename).split(".")[0]
 
     def _get_hvals(self):
-        # The entries in this header are capitalized and named to match Table 4
-        # in the GADGET-2 user guide.
-        gformat = _get_gadget_format(self.parameter_filename)
-        f = open(self.parameter_filename, 'rb')
-        if gformat[0] == 2:
-            f.seek(f.tell() + SNAP_FORMAT_2_OFFSET)
-        hvals = read_record(f, self._header_spec, endian=gformat[1])
-        for i in hvals:
-            if len(hvals[i]) == 1:
-                hvals[i] = hvals[i][0]
-        return hvals
+        return self._header.value
 
     def _parse_parameter_file(self):
 
@@ -202,10 +314,25 @@ class GadgetDataset(SPHDataset):
 
         self.cosmological_simulation = 1
 
-        self.current_redshift = hvals["Redshift"]
-        self.omega_lambda = hvals["OmegaLambda"]
-        self.omega_matter = hvals["Omega0"]
-        self.hubble_constant = hvals["HubbleParam"]
+        try:
+            self.current_redshift = hvals["Redshift"]
+        except KeyError:
+            # Probably not a cosmological dataset, we should just set
+            # z = 0 and let the user know
+            self.current_redshift = 0.0
+            only_on_root(
+                mylog.info, "Redshift is not set in Header. Assuming z=0.")
+
+        try:
+            self.omega_lambda = hvals["OmegaLambda"]
+            self.omega_matter = hvals["Omega0"]
+            self.hubble_constant = hvals["HubbleParam"]
+        except KeyError:
+            # If these are not set it is definitely not a cosmological dataset.
+            self.omega_lambda = 0.0
+            self.omega_matter = 1.0  # Just in case somebody asks for it.
+            # Hubble is set below for Omega Lambda = 0.
+
         # According to the Gadget manual, OmegaLambda will be zero for
         # non-cosmological datasets.  However, it may be the case that
         # individuals are running cosmological simulations *without* Lambda, in
@@ -322,65 +449,26 @@ class GadgetDataset(SPHDataset):
             vel_unit = self.velocity_unit
         self.time_unit = self.length_unit / vel_unit
 
-    @staticmethod
-    def _validate_header(filename):
-        '''
-        This method automatically detects whether the Gadget file is big/little endian
-        and is not corrupt/invalid using the first 4 bytes in the file.  It returns a
-        tuple of (Valid, endianswap) where Valid is a boolean that is true if the file
-        is a Gadget binary file, and endianswap is the endianness character '>' or '<'.
-        '''
-        try:
-            f = open(filename, 'rb')
-        except IOError:
-            try:
-                f = open(filename + ".0")
-            except IOError:
-                return False, 1
-
-        # First int32 is 256 for a Gadget2 binary file with SnapFormat=1,
-        # 8 for a Gadget2 binary file with SnapFormat=2 file,
-        # or the byte swapped equivalents (65536 and 134217728).
-        # The int32 following the header (first 4+256 bytes) must equal this
-        # number.
-        try:
-            (rhead,) = struct.unpack('<I', f.read(4))
-        except struct.error:
-            f.close()
-            return False, 1
-        # Use value to check endianess
-        if rhead == 256:
-            endianswap = '<'
-        elif rhead == 65536:
-            endianswap = '>'
-        elif rhead in (8, 134217728):
-            # This is only true for snapshot format 2
-            # we do not currently support double precision
-            # snap format 2 data
-            f.close()
-            return True, 'f4'
+        if "specific_energy" in unit_base:
+            specific_energy_unit = unit_base["specific_energy"]
+        elif "UnitEnergy_in_cgs" in unit_base and "UnitMass_in_g" in unit_base:
+            specific_energy_unit = \
+                unit_base["UnitEnergy_in_cgs"] / unit_base["UnitMass_in_g"]
+            specific_energy_unit = (specific_energy_unit, "(cm/s)**2")
         else:
-            f.close()
-            return False, 1
-        # Read in particle number from header
-        np0 = sum(struct.unpack(endianswap + 'IIIIII', f.read(6 * 4)))
-        # Read in size of position block. It should be 4 bytes per float,
-        # with 3 coordinates (x,y,z) per particle. (12 bytes per particle)
-        f.seek(4 + 256 + 4, 0)
-        np1 = struct.unpack(endianswap + 'I', f.read(4))[0] / (4 * 3)
-        f.close()
-        # Compare
-        if np0 == np1:
-            return True, 'f4'
-        elif np1 == 2*np0:
-            return True, 'f8'
-        else:
-            return False, 1
+            # Sane default
+            specific_energy_unit = (1, "(km/s) ** 2")
+        specific_energy_unit = _fix_unit_ordering(specific_energy_unit)
+        self.specific_energy_unit = self.quan(*specific_energy_unit)
 
     @classmethod
-    def _is_valid(self, *args, **kwargs):
-        # First 4 bytes used to check load
-        return GadgetDataset._validate_header(args[0])[0]
+    def _is_valid(cls, *args, **kwargs):
+        if 'header_spec' in kwargs:
+            header_spec = kwargs['header_spec']
+        else:
+            header_spec = 'default'
+        header = GadgetBinaryHeader(args[0], header_spec)
+        return header.validate()
 
 
 class GadgetHDF5Dataset(GadgetDataset):
@@ -468,12 +556,16 @@ class GadgetHDF5Dataset(GadgetDataset):
 
         # note the contents of the HDF5 Units group are in _unit_base
         # note the velocity stored on disk is sqrt(a) dx/dt
+        # physical velocity [cm/s] = a dx/dt = sqrt(a) * velocity_on_disk * UnitVelocity_in_cm_per_s
         self.length_unit = self.quan(
             self._unit_base["UnitLength_in_cm"], 'cmcm/h')
-        self.mass_unit = self.quan(self._unit_base["UnitMass_in_g"], 'g/h')
+        self.mass_unit = self.quan(self._unit_base["UnitMass_in_g"], 'g/h')      
         self.velocity_unit = self.quan(
-            self._unit_base["UnitVelocity_in_cm_per_s"], 'cm/s')
+            self._unit_base["UnitVelocity_in_cm_per_s"], 'cm/s * sqrt(a)')
         self.time_unit = self.quan(self._unit_base["UnitTime_in_s"], 's/h')
+        
+        specific_energy_unit_cgs = self._unit_base["UnitEnergy_in_cgs"] / self._unit_base["UnitMass_in_g"]
+        self.specific_energy_unit = self.quan(specific_energy_unit_cgs, '(cm/s)**2')
 
     @classmethod
     def _is_valid(self, *args, **kwargs):
