@@ -23,6 +23,7 @@ from yt.utilities.answer_testing.framework import \
     data_dir_load, \
     sph_answer
 from yt.frontends.owls.api import OWLSDataset
+from yt.data_objects.particle_filters import add_particle_filter
 
 os33 = "snapshot_033/snap_033.0.hdf5"
 
@@ -54,3 +55,19 @@ def test_snapshot_033():
 @requires_file(os33)
 def test_OWLSDataset():
     assert isinstance(data_dir_load(os33), OWLSDataset)
+    
+    
+@requires_ds(os33)
+def test_OWLS_particlefilter():
+    ds = data_dir_load(os33)
+    ad = ds.all_data()
+    def cold_gas(pfilter, data):
+        temperature = data[pfilter.filtered_type, "Temperature"]
+        filter = (temperature.in_units('K') <= 1e5)
+        return filter
+    add_particle_filter("gas_cold", function=cold_gas, filtered_type='PartType0', requires=["Temperature"])
+    ds.add_particle_filter('gas_cold')
+
+    mask = (ad['PartType0','Temperature'] <= 1e5)
+    assert ad['PartType0','Temperature'][mask].shape == ad['gas_cold','Temperature'].shape
+
