@@ -14,27 +14,9 @@ Octree geometry handler
 # The full license is in the file COPYING.txt, distributed with this software.
 #-----------------------------------------------------------------------------
 
-import h5py
-import numpy as np
-import string, re, gc, time
-from yt.extern.six.moves import cPickle
-from yt.extern.six.moves import zip as izip
-import weakref
-
-from itertools import chain
-
-from yt.funcs import *
 from yt.utilities.logger import ytLogger as mylog
-from yt.arraytypes import blankRecordArray
-from yt.config import ytcfg
-from yt.fields.field_info_container import NullFunc
-from yt.geometry.geometry_handler import Index, YTDataChunk
-from yt.utilities.definitions import MAXLEVEL
-from yt.utilities.io_handler import io_registry
-from yt.utilities.parallel_tools.parallel_analysis_interface import \
-    ParallelAnalysisInterface
+from yt.geometry.geometry_handler import Index
 
-from yt.data_objects.data_containers import data_object_registry
 
 class OctreeIndex(Index):
     """The Index subclass for oct AMR datasets"""
