@@ -1,10 +1,9 @@
 """
 Cosmology calculator.
 Cosmology calculator based originally on http://www.kempner.net/cosmic.php 
-and featuring time and redshift conversion functions from Enzo..
+and featuring time and redshift conversion functions from Enzo.
 
 """
-from __future__ import print_function
 
 #-----------------------------------------------------------------------------
 # Copyright (c) 2013-2014, yt Development Team.
@@ -34,7 +33,14 @@ class Cosmology(object):
 
     For an explanation of the various cosmological measures, see, for example 
     Hogg (1999, http://xxx.lanl.gov/abs/astro-ph/9905116).
-    
+
+    WARNING: Cosmological distance calculations return values that are either
+    in the comoving or proper frame, depending on the specific quantity.  For
+    simplicity, the proper and comoving frames are set equal to each other
+    within the cosmology calculator.  This means that for some distance value,
+    x, x.to("Mpc") and x.to("Mpccm") will be the same.  The user should take
+    care to understand which reference frame is correct for the given calculation.
+
     Parameters
     ----------
     hubble_constant : float
@@ -49,23 +55,41 @@ class Cosmology(object):
     omega_curvature : the fraction of the energy density of the Universe in 
         curvature.
         Default: 0.0.
+    unit_system : :class:`yt.units.unit_systems.UnitSystem`, optional
+        The units system to use when making calculations. If not specified,
+        cgs units are assumed.
+    use_dark_factor: Bool, optional
+        The flag to either use the cosmological constant (False, default)
+        or to use the parameterization of w(a) as given in Linder 2002. This,
+        along with w_0 and w_a, only matters in the function expansion_factor.
+    w_0 : float, optional
+        The Linder 2002 parameterization of w(a) is: w(a) = w_0 + w_a(1 - a).
+        w_0 is w(a = 1). Only matters if use_dark_factor = True. Default is None.
+        Cosmological constant case corresponds to w_0 = -1.
+    w_a : float, optional
+        See w_0. w_a is the derivative of w(a) evaluated at a = 1. Cosmological
+        constant case corresponds to w_a = 0. Default is None. 
 
     Examples
     --------
 
     >>> from yt.utilities.cosmology import Cosmology
     >>> co = Cosmology()
-    >>> print co.hubble_time(0.0).in_units("Gyr")
-    
+    >>> print(co.hubble_time(0.0).in_units("Gyr"))
+
     """
     def __init__(self, hubble_constant = 0.71,
                  omega_matter = 0.27,
                  omega_lambda = 0.73,
                  omega_curvature = 0.0,
-                 unit_registry = None):
-        self.omega_matter = omega_matter
-        self.omega_lambda = omega_lambda
-        self.omega_curvature = omega_curvature
+                 unit_registry = None,
+                 unit_system = "cgs",
+                 use_dark_factor = False,
+                 w_0 = -1.0,
+                 w_a = 0.0):
+        self.omega_matter = float(omega_matter)
+        self.omega_lambda = float(omega_lambda)
+        self.omega_curvature = float(omega_curvature)
         if unit_registry is None:
             unit_registry = UnitRegistry()
             unit_registry.modify("h", hubble_constant)
@@ -76,13 +100,20 @@ class Cosmology(object):
                                   dimensions.length, "\\rm{%s}/(1+z)" % my_unit)
         self.unit_registry = unit_registry
         self.hubble_constant = self.quan(hubble_constant, "100*km/s/Mpc")
+        self.unit_system = unit_system
+        
+        # For non-standard dark energy. If false, use default cosmological constant
+        # This only affects the expansion_factor function.
+        self.use_dark_factor = use_dark_factor
+        self.w_0 = w_0
+        self.w_a = w_a
 
     def hubble_distance(self):
         r"""
         The distance corresponding to c / h, where c is the speed of light 
         and h is the Hubble parameter in units of 1 / time.
         """
-        return self.quan((speed_of_light_cgs / self.hubble_constant)).in_cgs()
+        return self.quan((speed_of_light_cgs / self.hubble_constant)).in_base(self.unit_system)
 
     def comoving_radial_distance(self, z_i, z_f):
         r"""
@@ -99,12 +130,13 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.comoving_radial_distance(0., 1.).in_units("Mpccm")
+        >>> print(co.comoving_radial_distance(0., 1.).in_units("Mpccm"))
         
         """
         return (self.hubble_distance() *
-                trapzint(self.inverse_expansion_factor, z_i, z_f)).in_cgs()
+                trapzint(self.inverse_expansion_factor, z_i, z_f)).in_base(self.unit_system)
 
     def comoving_transverse_distance(self, z_i, z_f):
         r"""
@@ -122,21 +154,22 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.comoving_transverse_distance(0., 1.).in_units("Mpccm")
+        >>> print(co.comoving_transverse_distance(0., 1.).in_units("Mpccm"))
         
         """
         if (self.omega_curvature > 0):
             return (self.hubble_distance() / np.sqrt(self.omega_curvature) * 
                     np.sinh(np.sqrt(self.omega_curvature) * 
                             self.comoving_radial_distance(z_i, z_f) /
-                            self.hubble_distance())).in_cgs()
+                            self.hubble_distance())).in_base(self.unit_system)
         elif (self.omega_curvature < 0):
             return (self.hubble_distance() /
                     np.sqrt(np.fabs(self.omega_curvature)) * 
                     np.sin(np.sqrt(np.fabs(self.omega_curvature)) * 
                            self.comoving_radial_distance(z_i, z_f) /
-                           self.hubble_distance())).in_cgs()
+                           self.hubble_distance())).in_base(self.unit_system)
         else:
             return self.comoving_radial_distance(z_i, z_f)
 
@@ -156,8 +189,9 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.comoving_volume(0., 1.).in_units("Gpccm**3")
+        >>> print(co.comoving_volume(0., 1.).in_units("Gpccm**3"))
 
         """
         if (self.omega_curvature > 0):
@@ -166,28 +200,28 @@ class Cosmology(object):
                      (self.comoving_transverse_distance(z_i, z_f) /
                       self.hubble_distance() * 
                       np.sqrt(1 + self.omega_curvature * 
-                           sqr(self.comoving_transverse_distance(z_i, z_f) /
+                           np.sqrt(self.comoving_transverse_distance(z_i, z_f) /
                                self.hubble_distance())) - 
                       np.sinh(np.fabs(self.omega_curvature) * 
                             self.comoving_transverse_distance(z_i, z_f) /
                             self.hubble_distance()) /
-                            np.sqrt(self.omega_curvature))).in_cgs()
+                            np.sqrt(self.omega_curvature))).in_base(self.unit_system)
         elif (self.omega_curvature < 0):
              return (2 * np.pi * np.power(self.hubble_distance(), 3) /
                      np.fabs(self.omega_curvature) * 
                      (self.comoving_transverse_distance(z_i, z_f) /
                       self.hubble_distance() * 
                       np.sqrt(1 + self.omega_curvature * 
-                           sqr(self.comoving_transverse_distance(z_i, z_f) /
+                           np.sqrt(self.comoving_transverse_distance(z_i, z_f) /
                                self.hubble_distance())) - 
                       np.arcsin(np.fabs(self.omega_curvature) * 
                            self.comoving_transverse_distance(z_i, z_f) /
                            self.hubble_distance()) /
-                      np.sqrt(np.fabs(self.omega_curvature)))).in_cgs()
+                      np.sqrt(np.fabs(self.omega_curvature)))).in_base(self.unit_system)
         else:
              return (4 * np.pi *
                      np.power(self.comoving_transverse_distance(z_i, z_f), 3) /\
-                     3).in_cgs()
+                     3).in_base(self.unit_system)
 
     def angular_diameter_distance(self, z_i, z_f):
         r"""
@@ -204,13 +238,14 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.angular_diameter_distance(0., 1.).in_units("Mpc")
+        >>> print(co.angular_diameter_distance(0., 1.).in_units("Mpc"))
         
         """
         
         return (self.comoving_transverse_distance(0, z_f) / (1 + z_f) - 
-                self.comoving_transverse_distance(0, z_i) / (1 + z_i)).in_cgs()
+                self.comoving_transverse_distance(0, z_i) / (1 + z_i)).in_base(self.unit_system)
 
     def angular_scale(self, z_i, z_f):
         r"""
@@ -227,14 +262,16 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.angular_scale(0., 1.).in_units("kpc / arcsec")
+        >>> print(co.angular_scale(0., 1.).in_units("kpc / arcsec"))
         
         """
 
-        return self.angular_diameter_distance(z_i, z_f) / \
+        scale = self.angular_diameter_distance(z_i, z_f) / \
           self.quan(1, "radian")
-
+        return scale.in_base(self.unit_system)
+    
     def luminosity_distance(self, z_i, z_f):
         r"""
         The distance that would be inferred from the inverse-square law of 
@@ -250,13 +287,14 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.luminosity_distance(0., 1.).in_units("Mpc")
+        >>> print(co.luminosity_distance(0., 1.).in_units("Mpc"))
         
         """
 
         return (self.comoving_transverse_distance(0, z_f) * (1 + z_f) - 
-                self.comoving_transverse_distance(0, z_i) * (1 + z_i)).in_cgs()
+                self.comoving_transverse_distance(0, z_i) * (1 + z_i)).in_base(self.unit_system)
 
     def lookback_time(self, z_i, z_f):
         r"""
@@ -273,12 +311,13 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.lookback_time(0., 1.).in_units("Gyr")
+        >>> print(co.lookback_time(0., 1.).in_units("Gyr"))
 
         """
         return (trapzint(self.age_integrand, z_i, z_f) / \
-                self.hubble_constant).in_cgs()
+                self.hubble_constant).in_base(self.unit_system)
     
     def hubble_time(self, z, z_inf=1e6):
         r"""
@@ -295,8 +334,9 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.hubble_time(0.).in_units("Gyr")
+        >>> print(co.hubble_time(0.).in_units("Gyr"))
 
         See Also
         --------
@@ -305,7 +345,7 @@ class Cosmology(object):
 
         """
         return (trapzint(self.age_integrand, z, z_inf) /
-                self.hubble_constant).in_cgs()
+                self.hubble_constant).in_base(self.unit_system)
 
     def critical_density(self, z):
         r"""
@@ -320,15 +360,16 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.critical_density(0.).in_units("g/cm**3")
-        >>> print co.critical_density(0).in_units("Msun/Mpc**3")
+        >>> print(co.critical_density(0.).in_units("g/cm**3"))
+        >>> print(co.critical_density(0).in_units("Msun/Mpc**3"))
         
         """
         return (3.0 / 8.0 / np.pi * 
                 self.hubble_constant**2 / G *
                 ((1 + z)**3.0 * self.omega_matter + 
-                 self.omega_lambda)).in_cgs()
+                 self.omega_lambda)).in_base(self.unit_system)
 
     def hubble_parameter(self, z):
         r"""
@@ -342,11 +383,12 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.hubble_parameter(1.0).in_units("km/s/Mpc")
+        >>> print(co.hubble_parameter(1.0).in_units("km/s/Mpc"))
 
         """
-        return self.hubble_constant * self.expansion_factor(z)
+        return self.hubble_constant.in_base(self.unit_system) * self.expansion_factor(z)
 
     def age_integrand(self, z):
         return (1 / (z + 1) / self.expansion_factor(z))
@@ -360,9 +402,18 @@ class Cosmology(object):
         cosmological distances.
         
         """
+
+        # Use non-standard dark energy
+        if self.use_dark_factor:
+            dark_factor = self.get_dark_factor(z)
+
+        # Use default cosmological constant
+        else:
+            dark_factor = 1.0
+
         return np.sqrt(self.omega_matter * ((1 + z)**3.0) + 
                        self.omega_curvature * ((1 + z)**2.0) + 
-                       self.omega_lambda)
+                       (self.omega_lambda * dark_factor))
 
     def inverse_expansion_factor(self, z):
         return 1 / self.expansion_factor(z)
@@ -387,8 +438,9 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.z_from_t(4.e17)
+        >>> print(co.z_from_t(4.e17))
 
         """
 
@@ -478,8 +530,9 @@ class Cosmology(object):
         Examples
         --------
 
+        >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print co.t_from_z(0.).in_units("Gyr")
+        >>> print(co.t_from_z(0.).in_units("Gyr"))
 
         See Also
         --------
@@ -522,7 +575,32 @@ class Cosmology(object):
   
         my_time = t0 / self.hubble_constant
     
-        return my_time.in_cgs()
+        return my_time.in_base(self.unit_system)
+
+    def get_dark_factor(self, z):
+        """
+        This function computes the additional term that enters the expansion factor
+        when using non-standard dark energy. See Dolag et al 2004 eq. 7 for ref (but
+        note that there's a typo in his eq. There should be no negative sign).
+
+        At the moment, this only works using the parameterization given in Linder 2002
+        eq. 7: w(a) = w0 + wa(1 - a) = w0 + wa * z / (1+z). This gives rise to an analytic
+        expression. It is also only functional for Gadget simulations, at the moment.
+
+        Parameters
+        ----------
+        z:  float
+            Redshift
+        """
+
+        # Get value of scale factor a corresponding to redshift z
+        scale_factor = 1.0 / (1.0 + z)
+
+        # Evaluate exponential using Linder02 parameterization
+        dark_factor = np.power(scale_factor, -3.0 * (1.0 + self.w_0 + self.w_a)) * \
+                      np.exp(-3.0 * self.w_a * (1.0 - scale_factor))
+
+        return dark_factor
 
     _arr = None
     @property
