@@ -12,17 +12,22 @@
 #-----------------------------------------------------------------------------
 import numpy as np
 
-import matplotlib
 import matplotlib.colors as cc
 import matplotlib.cm as mcm
 from . import _colormap_data as _cm
+from yt.extern.six import string_types
+
+try:
+    import cmocean
+except ImportError:
+    cmocean = None
 
 def is_colormap(cmap):
     return isinstance(cmap,cc.Colormap)
 
 def check_color(name):
     try:
-        ss = cc.colorConverter.to_rgb(name)
+        cc.colorConverter.to_rgb(name)
         return True
     except ValueError:
         return False
@@ -71,9 +76,6 @@ cdict = {'red':   ((0.0, 80/256., 80/256.),
 add_cmap('bds_highcontrast', cdict)
 add_cmap('algae', cdict)
 
-# Set the default colormap to be algae.
-matplotlib.rc('image', cmap="algae")
-
 # This next colormap was designed by Tune Kamae and converted here by Matt
 _vs = np.linspace(0,1,255)
 _kamae_red = np.minimum(255,
@@ -101,6 +103,15 @@ cdict = {'red':   ((0.0, 0.0, 0.0),
 
 add_cmap('black_green', cdict)
 
+cdict = {'red':   ((0.0, 0.0, 0.0),
+                   (1.0, 0.2, 0.2)),
+         'green': ((0.0, 0.0, 0.0),
+                   (1.0, 0.2, 0.2)),
+         'blue':  ((0.0, 0.0, 0.0),
+                   (1.0, 1.0, 1.0))}
+
+add_cmap('black_blueish', cdict)
+
 # This one is a variant of a colormap commonly
 # used for X-ray observations by Maxim Markevitch
 
@@ -146,6 +157,22 @@ _cubehelix_data = {
 
 add_cmap("cubehelix", _cubehelix_data)
 
+# Add colormaps from cmocean, if it's installed
+if cmocean is not None:
+    for cmname in cmocean.cm.cmapnames:
+        cm = getattr(cmocean.cm, cmname)
+        # cmocean has a colormap named 'algae', so let's avoid overwriting
+        # yt's algae or any other colormap we've already added
+        if cmname in yt_colormaps:
+            cmname = cmname + '_cmocean'
+        yt_colormaps[cmname] = cm
+        try:
+            mcm.register_cmap(cmname, yt_colormaps[cmname])
+        except AttributeError:
+            # for old versions of matplotlib this won't work, so we avoid
+            # erroring out but don't worry about registering with matplotlib
+            pass
+
 # Add colormaps in _colormap_data.py that weren't defined here
 _vs = np.linspace(0,1,256)
 for k,v in list(_cm.color_map_luts.items()):
@@ -201,16 +228,17 @@ def show_colormaps(subset="all", filename=None):
         If filename is set, then it will save the colormaps to an output
         file.  If it is not set, it will "show" the result interactively.
     """
-    import pylab as pl
+    import matplotlib.pyplot as plt
+    import matplotlib.cm as cm
 
     a=np.outer(np.arange(0,1,0.01), np.ones(10))
     if subset == "all":
-        maps = [ m for m in pl.cm.datad if (not m.startswith("idl")) & (not m.endswith("_r"))]
+        maps = [ m for m in cm.cmap_d if (not m.startswith("idl")) & (not m.endswith("_r"))]
     elif subset == "yt_native":
         maps = [ m for m in _cm.color_map_luts if (not m.startswith("idl")) & (not m.endswith("_r"))]
     else:
         try:
-            maps = [ m for m in pl.cm.datad if m in subset]
+            maps = [ m for m in cm.cmap_d if m in subset]
             if len(maps) == 0:
                 raise AttributeError
         except AttributeError:
@@ -220,18 +248,18 @@ def show_colormaps(subset="all", filename=None):
     maps = list(set(maps))
     maps.sort()
     # scale the image size by the number of cmaps
-    pl.figure(figsize=(2.*len(maps)/10.,6))
-    pl.subplots_adjust(top=0.7,bottom=0.05,left=0.01,right=0.99)
+    plt.figure(figsize=(2.*len(maps)/10.,6))
+    plt.subplots_adjust(top=0.7,bottom=0.05,left=0.01,right=0.99)
     l = len(maps)+1
     for i,m in enumerate(maps):
-        pl.subplot(1,l,i+1)
-        pl.axis("off")
-        pl.imshow(a, aspect='auto',cmap=pl.get_cmap(m),origin="lower")      
-        pl.title(m,rotation=90, fontsize=10, verticalalignment='bottom')
+        plt.subplot(1,l,i+1)
+        plt.axis("off")
+        plt.imshow(a, aspect='auto',cmap=plt.get_cmap(m),origin="lower")      
+        plt.title(m,rotation=90, fontsize=10, verticalalignment='bottom')
     if filename is not None:
-        pl.savefig(filename, dpi=100, facecolor='gray') 
+        plt.savefig(filename, dpi=100, facecolor='gray') 
     else:  
-        pl.show()
+        plt.show()
 
 def make_colormap(ctuple_list, name=None, interpolate=True):
     """
@@ -356,7 +384,7 @@ def make_colormap(ctuple_list, name=None, interpolate=True):
     # Figure out how many intervals there are total.
     rolling_index = 0
     for i, (color, interval) in enumerate(ctuple_list):
-        if isinstance(color, str):
+        if isinstance(color, string_types):
             ctuple_list[i] = (color_dict[color], interval)
         rolling_index += interval
     scale = 256./rolling_index
@@ -378,7 +406,7 @@ def make_colormap(ctuple_list, name=None, interpolate=True):
         # Use np.round to make sure you're on a discrete index
         interval = np.round(next_index)-np.round(rolling_index)
         for j in np.arange(3):
-            cmap[np.round(rolling_index):np.round(next_index), j] = \
+            cmap[int(np.rint(rolling_index)):int(np.rint(next_index)), j] = \
                 np.linspace(color[j], next_color[j], interval)
 
         rolling_index = next_index
