@@ -18,6 +18,7 @@ from yt.extern.six.moves import builtins
 from yt.extern.six.moves import zip as izip
 from yt.extern.six import string_types, iteritems
 from collections import OrderedDict
+from distutils.version import LooseVersion
 import base64
 import os
 from functools import wraps
@@ -33,6 +34,10 @@ from .plot_container import \
     validate_plot, invalidate_plot
 from yt.data_objects.profiles import \
     create_profile
+from yt.data_objects.static_output import \
+    Dataset
+from yt.data_objects.data_containers import \
+    YTSelectionContainer
 from yt.frontends.ytdata.data_structures import \
     YTProfileDataset
 from yt.utilities.exceptions import \
@@ -118,6 +123,15 @@ def sanitize_label(label, nprofiles):
 
     return label
 
+def data_object_or_all_data(data_source):
+    if isinstance(data_source, Dataset):
+        data_source = data_source.all_data()
+
+    if not isinstance(data_source, YTSelectionContainer):
+        raise RuntimeError("data_source must be a yt selection data object")
+
+    return data_source
+
 class ProfilePlot(object):
     r"""
     Create a 1d profile plot from a data source or from a list 
@@ -135,7 +149,8 @@ class ProfilePlot(object):
     ----------
     data_source : YTSelectionContainer Object
         The data object to be profiled, such as all_data, region, or 
-        sphere.
+        sphere. If a dataset is passed in instead, an all_data data object
+        is generated internally from the dataset.
     x_field : str
         The binning field for the profile.
     y_fields : str or list
@@ -209,6 +224,7 @@ class ProfilePlot(object):
     Use set_line_property to change line properties of one or all profiles.
     
     """
+
     x_log = None
     y_log = None
     x_title = None
@@ -221,6 +237,8 @@ class ProfilePlot(object):
                  label=None, plot_spec=None,
                  x_log=None, y_log=None):
 
+        data_source = data_object_or_all_data(data_source)
+
         if x_log is None:
             logs = None
         else:
@@ -349,6 +367,12 @@ class ProfilePlot(object):
             return
         for f in self.axes:
             self.axes[f].cla()
+            if f in self._plot_text:
+                self.plots[f].axes.text(self._text_xpos[f], self._text_ypos[f],
+                                        self._plot_text[f],
+                                        fontproperties=self._font_properties,
+                                        **self._text_kwargs[f])
+
         for i, profile in enumerate(self.profiles):
             for field, field_data in profile.items():
                 self.axes[field].plot(np.array(profile.x), np.array(field_data),
@@ -359,12 +383,19 @@ class ProfilePlot(object):
                 axes = self.axes[fname]
                 xscale, yscale = self._get_field_log(fname, profile)
                 xtitle, ytitle = self._get_field_title(fname, profile)
+
                 axes.set_xscale(xscale)
                 axes.set_yscale(yscale)
-                axes.set_xlabel(xtitle)
+
                 axes.set_ylabel(ytitle)
+                axes.set_xlabel(xtitle)
+
                 axes.set_ylim(*self.axes.ylim[fname])
                 axes.set_xlim(*self.axes.xlim)
+
+                if fname in self._plot_title:
+                    axes.set_title(self._plot_title[fname])
+
                 if any(self.label):
                     axes.legend(loc="best")
         self._set_font_properties()
@@ -372,6 +403,12 @@ class ProfilePlot(object):
 
     @classmethod
     def _initialize_instance(cls, obj, profiles, labels, plot_specs, y_log):
+        obj._plot_title = {}
+        obj._plot_text = {}
+        obj._text_xpos = {}
+        obj._text_ypos = {}
+        obj._text_kwargs = {}
+
         from matplotlib.font_manager import FontProperties
         obj._font_properties = FontProperties(family='stixgeneral', size=18)
         obj._font_color = None
@@ -383,6 +420,7 @@ class ProfilePlot(object):
                 field, = obj.profiles[0].data_source._determine_fields([field])
                 obj.y_log[field] = log
         obj.y_title = {}
+        obj.x_title = None
         obj.label = sanitize_label(labels, len(obj.profiles))
         if plot_specs is None:
             plot_specs = [dict() for p in obj.profiles]
@@ -501,6 +539,44 @@ class ProfilePlot(object):
                 raise KeyError("Field %s not in profile plot!" % (field))
         return self
 
+
+    @invalidate_plot
+    def set_ylabel(self, field, label):
+        """Sets a new ylabel for the specified fields
+
+        Parameters
+        ----------
+        field : string
+           The name of the field that is to be changed.
+
+        label : string
+           The label to be placed on the y-axis
+        """
+        if field == "all":
+            for field in self.profiles[0].field_data:
+                self.y_title[field] = label
+        else:
+            field, = self.profiles[0].data_source._determine_fields([field])
+            if field in self.profiles[0].field_data:
+                self.y_title[field] = label
+            else:
+                raise KeyError("Field %s not in profile plot!" % (field))
+
+        return self
+
+    @invalidate_plot
+    def set_xlabel(self, label):
+        """Sets a new xlabel for all profiles
+
+        Parameters
+        ----------
+        label : string
+           The label to be placed on the x-axis
+        """
+        self.x_title = label
+
+        return self
+
     @invalidate_plot
     def set_unit(self, field, unit):
         """Sets a new unit for the requested field
@@ -513,10 +589,11 @@ class ProfilePlot(object):
         new_unit : string or Unit object
            The name of the new unit.
         """
+        fd = self.profiles[0].data_source._determine_fields(field)[0]
         for profile in self.profiles:
-            if field == profile.x_field[1]:
+            if fd == profile.x_field:
                 profile.set_x_unit(unit)
-            elif field in self.profiles[0].field_map:
+            elif fd[1] in self.profiles[0].field_map:
                 profile.set_field_unit(field, unit)
             else:
                 raise KeyError("Field %s not in profile plot!" % (field))
@@ -667,6 +744,97 @@ class ProfilePlot(object):
 
         return (x_title, y_title)
 
+    @invalidate_plot
+    def annotate_title(self, title, field='all'):
+        r"""Set a title for the plot.
+
+        Parameters
+        ----------
+        title : str
+          The title to add.
+        field : str or list of str
+          The field name for which title needs to be set.
+
+        Examples
+        --------
+        >>> # To set title for all the fields:
+        >>> plot.annotate_title("This is a Profile Plot")
+
+        >>> # To set title for specific fields:
+        >>> plot.annotate_title("Profile Plot for Temperature", "temperature")
+
+        >>> # Setting same plot title for both the given fields
+        >>> plot.annotate_title("Profile Plot: Temperature-Dark Matter Density",
+                                ["temperature", "dark_matter_density"])
+
+        """
+        if field is 'all':
+            fields = list(self.axes.keys())
+        else:
+            fields = ensure_list(field)
+        for profile in self.profiles:
+            for field in profile.data_source._determine_fields(fields):
+                if field in profile.field_map:
+                    field = profile.field_map[field]
+                self._plot_title[field] = title
+        return self
+
+    @invalidate_plot
+    def annotate_text(self, xpos=0.0, ypos=0.0, text=None, field='all', **text_kwargs):
+        r"""Allow the user to insert text onto the plot
+
+        The x-position and y-position must be given as well as the text string.
+        Add *text* to plot at location *xpos*, *ypos* in plot coordinates for
+        the given fields or by default for all fields.
+        (see example below).
+
+        Parameters
+        ----------
+        xpos: float
+          Position on plot in x-coordinates.
+        ypos: float
+          Position on plot in y-coordinates.
+        text: str
+          The text to insert onto the plot.
+        field: str or tuple
+          The name of the field to add text to.
+        text_kwargs: dict
+          Dictionary of text keyword arguments to be passed to matplotlib
+
+        >>>  import yt
+        >>>  from yt.units import kpc
+        >>>  ds = yt.load('IsolatedGalaxy/galaxy0030/galaxy0030')
+        >>>  my_galaxy = ds.disk(ds.domain_center, [0.0, 0.0, 1.0], 10*kpc, 3*kpc)
+        >>>  plot = yt.ProfilePlot(my_galaxy, "density", ["temperature"])
+
+        >>>  # Annotate text for all the fields
+        >>>  plot.annotate_text(1e-26, 1e5, "This is annotated text in the plot area.")
+        >>>  plot.save()
+
+        >>>  # Annotate text for a given field
+        >>>  plot.annotate_text(1e-26, 1e5, "Annotated text", "Temperature")
+        >>>  plot.save()
+
+        >>>  # Annotate text for multiple fields
+        >>>  fields = ["temperature", "density"]
+        >>>  plot.annotate_text(1e-26, 1e5, "Annotated text", fields)
+        >>>  plot.save()
+
+        """
+        if field is 'all':
+            fields = list(self.axes.keys())
+        else:
+            fields = ensure_list(field)
+        for profile in self.profiles:
+            for field in profile.data_source._determine_fields(fields):
+                if field in profile.field_map:
+                    field = profile.field_map[field]
+                self._plot_text[field] = text
+                self._text_xpos[field] = xpos
+                self._text_ypos[field] = ypos
+                self._text_kwargs[field] = text_kwargs
+        return self
+
 class PhasePlot(ImagePlotContainer):
     r"""
     Create a 2d profile (phase) plot from a data source or from 
@@ -682,7 +850,8 @@ class PhasePlot(ImagePlotContainer):
     ----------
     data_source : YTSelectionContainer Object
         The data object to be profiled, such as all_data, region, or 
-        sphere.
+        sphere. If a dataset is passed in instead, an all_data data object
+        is generated internally from the dataset.
     x_field : str
         The x binning field for the profile.
     y_field : str
@@ -747,6 +916,8 @@ class PhasePlot(ImagePlotContainer):
                  accumulation=False, fractional=False,
                  fontsize=18, figure_size=8.0):
 
+        data_source = data_object_or_all_data(data_source)
+
         if isinstance(data_source.ds, YTProfileDataset):
             profile = data_source.ds.profile
         else:
@@ -916,6 +1087,13 @@ class PhasePlot(ImagePlotContainer):
             self.plots[f].axes.set_xlim(xlim)
             self.plots[f].axes.set_ylim(ylim)
 
+            color = self._background_color[f]
+
+            if LooseVersion(matplotlib.__version__) < LooseVersion("2.0.0"):
+                self.plots[f].axes.set_axis_bgcolor(color)
+            else:
+                self.plots[f].axes.set_facecolor(color)
+
             if f in self._plot_text:
                 self.plots[f].axes.text(self._text_xpos[f], self._text_ypos[f],
                                         self._plot_text[f],
@@ -1211,14 +1389,15 @@ class PhasePlot(ImagePlotContainer):
                 self.z_log[field] = log
             self._profile_valid = False
         else:
-            if field == p.x_field[1]:
+            field, = self.profile.data_source._determine_fields([field])
+            if field == p.x_field:
                 self.x_log = log
                 self._profile_valid = False
-            elif field == p.y_field[1]:
+            elif field == p.y_field:
                 self.y_log = log
                 self._profile_valid = False
-            elif field in p.field_map:
-                self.z_log[p.field_map[field]] = log
+            elif field in p.field_data:
+                self.z_log[field] = log
             else:
                 raise KeyError("Field %s not in phase plot!" % (field))
         return self
@@ -1235,12 +1414,12 @@ class PhasePlot(ImagePlotContainer):
         new_unit : string or Unit object
            The name of the new unit.
         """
-        fields = [fd[1] for fd in self.profile.field_data]
-        if field == self.profile.x_field[1]:
+        fd = self.data_source._determine_fields(field)[0]
+        if fd == self.profile.x_field:
             self.profile.set_x_unit(unit)
-        elif field == self.profile.y_field[1]:
+        elif fd == self.profile.y_field:
             self.profile.set_y_unit(unit)
-        elif field in fields:
+        elif fd in self.profile.field_data.keys():
             self.profile.set_field_unit(field, unit)
             self.plots[field].zmin, self.plots[field].zmax = (None, None)
         else:
